==> jc-1.4.0.tar.gz: soot/jimple/spark/sets/DoublePointsToSet__242.c <==
// class soot.jimple.spark.sets.DoublePointsToSet$2

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class b6d33af8f84fdbc4 soot_G
// @dep_class f801e5c664424a1 soot_Type
// @dep_class ebf774e64bb7347e soot_jimple_spark_pag_PAG
// @dep_class 6f2373c32f6791c5 soot_jimple_spark_sets_DoublePointsToSet
// @dep_class 89999a318a61acba soot_jimple_spark_sets_DoublePointsToSet__242
// @dep_class 4af9fec835f92d51 soot_jimple_spark_sets_P2SetFactory
// @dep_class bbf459c4685726ff soot_jimple_spark_sets_PointsToSetInternal

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_G
// @dep_header soot_Type
// @dep_header soot_jimple_spark_pag_PAG
// @dep_header soot_jimple_spark_sets_DoublePointsToSet
// @dep_header soot_jimple_spark_sets_DoublePointsToSet__242

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/G.h"
#include "soot/Type.h"
#include "soot/jimple/spark/pag/PAG.h"
#include "soot/jimple/spark/sets/DoublePointsToSet.h"
#include "soot/jimple/spark/sets/DoublePointsToSet__242.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_soot_jimple_spark_sets_DoublePointsToSet__242$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_sets_DoublePointsToSet__242, _init$52f4ad9f2989aeee);

void
_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *this)
{
	struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(118);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public soot.jimple.spark.sets.PointsToSetInternal newSet(soot.Type, soot.jimple.spark.pag.PAG)
//

static _jc_linenum _jc_soot_jimple_spark_sets_DoublePointsToSet__242$linenum_table$newSet$774f6a02bfa5ba98[];

static const unsigned char _jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_ptypes$newSet$774f6a02bfa5ba98[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_types$newSet$774f6a02bfa5ba98[] = {
	&_jc_soot_Type$type,
	&_jc_soot_jimple_spark_pag_PAG$type
};

_jc_method _jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$newSet$774f6a02bfa5ba98 = {
	.name=			"newSet",
	.signature=		"(Lsoot/Type;Lsoot/jimple/spark/pag/PAG;)Lsoot/jimple/spark/sets/PointsToSetInternal;",
	.class=			&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$type,
	.param_types=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_types$newSet$774f6a02bfa5ba98,
	.return_type=		&_jc_soot_jimple_spark_sets_PointsToSetInternal$type,
	.param_ptypes=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_ptypes$newSet$774f6a02bfa5ba98,
	.signature_hash=	_JC_JLONG(0x774f6a02bfa5ba98),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable, soot_jimple_spark_sets_DoublePointsToSet__242.newSet$774f6a02bfa5ba98) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$linenum_table$newSet$774f6a02bfa5ba98
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_sets_DoublePointsToSet__242, newSet$774f6a02bfa5ba98);

_jc_soot_jimple_spark_sets_PointsToSetInternal$object *
_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98(_jc_env *const env, _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *this, _jc_soot_Type$object *param0, _jc_soot_jimple_spark_pag_PAG$object *param1)
{
	struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *r0;
	struct _jc_soot_Type$object *r1;
	struct _jc_soot_jimple_spark_pag_PAG$object *r2;
	struct _jc_soot_jimple_spark_sets_DoublePointsToSet$object *r3;
	struct _jc_soot_jimple_spark_sets_P2SetFactory$object *r4;
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *r5;
	struct _jc_soot_G$object *r6;
	struct _jc_soot_G$object *r7;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(119);				// 0
	r3 = _JC_NEW(env, soot_jimple_spark_sets_DoublePointsToSet);
	_JC_REF_FIELD(env, r3, soot_jimple_spark_sets_PointsToSetInternal, type) = r1;
	_JC_ACTIVE_USE(env, soot_G);
	r6 = _JC_STATIC_FIELD(env, soot_G, instance, 1);
	r4 = _JC_REF_FIELD(env, r6, soot_G, newSetFactory);
	r5 = _JC_INVOKE_VIRTUAL(env, soot_jimple_spark_sets_P2SetFactory, newSet$774f6a02bfa5ba98, r4, r1, r2);
	_JC_REF_FIELD(env, r3, soot_jimple_spark_sets_DoublePointsToSet, newSet) = r5;
	r7 = _JC_STATIC_FIELD(env, soot_G, instance, 1);
	r4 = _JC_REF_FIELD(env, r7, soot_G, oldSetFactory);
	r5 = _JC_INVOKE_VIRTUAL(env, soot_jimple_spark_sets_P2SetFactory, newSet$774f6a02bfa5ba98, r4, r1, r2);
	_JC_REF_FIELD(env, r3, soot_jimple_spark_sets_DoublePointsToSet, oldSet) = r5;
	_JC_REF_FIELD(env, r3, soot_jimple_spark_sets_DoublePointsToSet, pag) = r2;
	return r3;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$methods[] = {
	&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$newSet$774f6a02bfa5ba98
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_58[] = {
	&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_81[] = {
	&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[58]=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_58,
	[81]=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_81,
	[113]=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/G",	_JC_JLONG(0xb6d33af8f84fdbc4) },
	{ "soot/Type",	_JC_JLONG(0xf801e5c664424a1) },
	{ "soot/jimple/spark/pag/PAG",	_JC_JLONG(0xebf774e64bb7347e) },
	{ "soot/jimple/spark/sets/DoublePointsToSet",	_JC_JLONG(0x6f2373c32f6791c5) },
	{ "soot/jimple/spark/sets/P2SetFactory",	_JC_JLONG(0x4af9fec835f92d51) },
	{ "soot/jimple/spark/sets/PointsToSetInternal",	_JC_JLONG(0xbbf459c4685726ff) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype _jc_soot_jimple_spark_sets_DoublePointsToSet__242$type = {
    .type= {
	.name=			"soot/jimple/spark/sets/DoublePointsToSet$2",
	.superclass=		&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x89999a318a61acba),
		.source_file=		"DoublePointsToSet.java",
		.instance_size=		sizeof(_jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs) + sizeof(_jc_soot_jimple_spark_sets_DoublePointsToSet__242$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_jimple_spark_sets_DoublePointsToSet__242$methods) / sizeof(*_jc_soot_jimple_spark_sets_DoublePointsToSet__242$methods),
		.methods=		_jc_soot_jimple_spark_sets_DoublePointsToSet__242$methods,
		.instanceof_hash_table=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_depends) / sizeof(*_jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_depends),
		.class_depends=		_jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_spark_sets_P2SetFactory= {
	    .newSet$774f6a02bfa5ba98=			// overridden
		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98,
	},
	.soot_jimple_spark_sets_DoublePointsToSet__242= {
	    .newSet$774f6a02bfa5ba98=
		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/jimple/spark/sets/DoublePointsToSet__242.c <==
// class soot.jimple.spark.sets.DoublePointsToSet$2

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class b6d33af8f84fdbc4 soot_G
// @dep_class f801e5c664424a1 soot_Type
// @dep_class ebf774e64bb7347e soot_jimple_spark_pag_PAG
// @dep_class 6f2373c32f6791c5 soot_jimple_spark_sets_DoublePointsToSet
// @dep_class 89999a318a61acba soot_jimple_spark_sets_DoublePointsToSet__242
// @dep_class 4af9fec835f92d51 soot_jimple_spark_sets_P2SetFactory
// @dep_class bbf459c4685726ff soot_jimple_spark_sets_PointsToSetInternal

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_G
// @dep_header soot_Type
// @dep_header soot_jimple_spark_pag_PAG
// @dep_header soot_jimple_spark_sets_DoublePointsToSet
// @dep_header soot_jimple_spark_sets_DoublePointsToSet__242

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/G.h"
#include "soot/Type.h"
#include "soot/jimple/spark/pag/PAG.h"
#include "soot/jimple/spark/sets/DoublePointsToSet.h"
#include "soot/jimple/spark/sets/DoublePointsToSet__242.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_soot_jimple_spark_sets_DoublePointsToSet__242$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_sets_DoublePointsToSet__242, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *this)
{
	struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(118);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public soot.jimple.spark.sets.PointsToSetInternal newSet(soot.Type, soot.jimple.spark.pag.PAG)
//

static _jc_linenum _jc_soot_jimple_spark_sets_DoublePointsToSet__242$linenum_table$newSet$774f6a02bfa5ba98[];

static const unsigned char _jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_ptypes$newSet$774f6a02bfa5ba98[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_types$newSet$774f6a02bfa5ba98[] = {
	&_jc_soot_Type$type,
	&_jc_soot_jimple_spark_pag_PAG$type
};

_jc_method _jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$newSet$774f6a02bfa5ba98 = {
	.name=			"newSet",
	.signature=		"(Lsoot/Type;Lsoot/jimple/spark/pag/PAG;)Lsoot/jimple/spark/sets/PointsToSetInternal;",
	.class=			&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$type,
	.param_types=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_types$newSet$774f6a02bfa5ba98,
	.return_type=		&_jc_soot_jimple_spark_sets_PointsToSetInternal$type,
	.param_ptypes=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$param_ptypes$newSet$774f6a02bfa5ba98,
	.signature_hash=	_JC_JLONG(0x774f6a02bfa5ba98),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable, soot_jimple_spark_sets_DoublePointsToSet__242.newSet$774f6a02bfa5ba98) / sizeof(void *),
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$linenum_table$newSet$774f6a02bfa5ba98
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_spark_sets_DoublePointsToSet__242, newSet$774f6a02bfa5ba98);

_jc_soot_jimple_spark_sets_PointsToSetInternal$object * _JC_JCNI_ATTR
_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98(_jc_env *const env, _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *this, _jc_soot_Type$object *param0, _jc_soot_jimple_spark_pag_PAG$object *param1)
{
	struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *r0;
	struct _jc_soot_Type$object *r1;
	struct _jc_soot_jimple_spark_pag_PAG$object *r2;
	struct _jc_soot_jimple_spark_sets_DoublePointsToSet$object *r3;
	struct _jc_soot_jimple_spark_sets_P2SetFactory$object *r4;
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *r5;
	struct _jc_soot_G$object *r6;
	struct _jc_soot_G$object *r7;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(119);				// 0
	r3 = _JC_NEW(env, soot_jimple_spark_sets_DoublePointsToSet);
	_JC_REF_FIELD(env, r3, soot_jimple_spark_sets_PointsToSetInternal, type) = r1;
	_JC_ACTIVE_USE(env, soot_G);
	r6 = _JC_STATIC_FIELD(env, soot_G, instance, 1);
	r4 = _JC_REF_FIELD(env, r6, soot_G, newSetFactory);
	r5 = _JC_INVOKE_VIRTUAL(env, soot_jimple_spark_sets_P2SetFactory, newSet$774f6a02bfa5ba98, r4, r1, r2);
	_JC_REF_FIELD(env, r3, soot_jimple_spark_sets_DoublePointsToSet, newSet) = r5;
	r7 = _JC_STATIC_FIELD(env, soot_G, instance, 1);
	r4 = _JC_REF_FIELD(env, r7, soot_G, oldSetFactory);
	r5 = _JC_INVOKE_VIRTUAL(env, soot_jimple_spark_sets_P2SetFactory, newSet$774f6a02bfa5ba98, r4, r1, r2);
	_JC_REF_FIELD(env, r3, soot_jimple_spark_sets_DoublePointsToSet, oldSet) = r5;
	_JC_REF_FIELD(env, r3, soot_jimple_spark_sets_DoublePointsToSet, pag) = r2;
	return r3;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$methods[] = {
	&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$newSet$774f6a02bfa5ba98
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_58[] = {
	&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_81[] = {
	&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[58]=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_58,
	[81]=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_81,
	[101]=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/G",	_JC_JLONG(0xb6d33af8f84fdbc4) },
	{ "soot/Type",	_JC_JLONG(0xf801e5c664424a1) },
	{ "soot/jimple/spark/pag/PAG",	_JC_JLONG(0xebf774e64bb7347e) },
	{ "soot/jimple/spark/sets/DoublePointsToSet",	_JC_JLONG(0x6f2373c32f6791c5) },
	{ "soot/jimple/spark/sets/P2SetFactory",	_JC_JLONG(0x4af9fec835f92d51) },
	{ "soot/jimple/spark/sets/PointsToSetInternal",	_JC_JLONG(0xbbf459c4685726ff) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype _jc_soot_jimple_spark_sets_DoublePointsToSet__242$type = {
    .type= {
	.name=			"soot/jimple/spark/sets/DoublePointsToSet$2",
	.superclass=		&_jc_soot_jimple_spark_sets_P2SetFactory$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x89999a318a61acba),
		.source_file=		"DoublePointsToSet.java",
		.instance_size=		sizeof(_jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs) + sizeof(_jc_soot_jimple_spark_sets_DoublePointsToSet__242$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_soot_jimple_spark_sets_DoublePointsToSet__242$methods) / sizeof(*_jc_soot_jimple_spark_sets_DoublePointsToSet__242$methods),
		.methods=		_jc_soot_jimple_spark_sets_DoublePointsToSet__242$methods,
		.instanceof_hash_table=	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_depends) / sizeof(*_jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_depends),
		.class_depends=		_jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_spark_sets_P2SetFactory= {
	    .newSet$774f6a02bfa5ba98=			// overridden
		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98,
	},
	.soot_jimple_spark_sets_DoublePointsToSet__242= {
	    .newSet$774f6a02bfa5ba98=
		&_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98,
	},
    }
};
